==> eam-wshub-proxyclient-11.4-5-sources.jar: net/datastream/schemas/mp_fields/WOLABORSCHEDULINGID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour WOLABORSCHEDULINGID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="WOLABORSCHEDULINGID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}WOLABORSCHEDULINGCODE"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "WOLABORSCHEDULINGID_Type", propOrder = {
    "wolaborschedulingcode"
})
public class WOLABORSCHEDULINGID_Type {

    @XmlElement(name = "WOLABORSCHEDULINGCODE", required = true)
    protected String wolaborschedulingcode;

    /**
     * Obtient la valeur de la propriété wolaborschedulingcode.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getWOLABORSCHEDULINGCODE() {
        return wolaborschedulingcode;
    }

    /**
     * Définit la valeur de la propriété wolaborschedulingcode.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setWOLABORSCHEDULINGCODE(String value) {
        this.wolaborschedulingcode = value;
    }

}

==> eam-wshub-proxyclient-11.7-3-sources.jar: net/datastream/schemas/mp_fields/WOLABORSCHEDULINGID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for WOLABORSCHEDULINGID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="WOLABORSCHEDULINGID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}WOLABORSCHEDULINGCODE"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "WOLABORSCHEDULINGID_Type", propOrder = {
    "wolaborschedulingcode"
})
public class WOLABORSCHEDULINGID_Type {

    @XmlElement(name = "WOLABORSCHEDULINGCODE", required = true)
    protected String wolaborschedulingcode;

    /**
     * Gets the value of the wolaborschedulingcode property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getWOLABORSCHEDULINGCODE() {
        return wolaborschedulingcode;
    }

    /**
     * Sets the value of the wolaborschedulingcode property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setWOLABORSCHEDULINGCODE(String value) {
        this.wolaborschedulingcode = value;
    }

}
